/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Faroese language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Fjal amboðsbjálkan",
ToolbarExpand		: "Vís amboðsbjálkan",

// Toolbar Items and Context Menu
Save				: "Goym",
NewPage				: "Nýggj síða",
Preview				: "Frumsýning",
Cut					: "Kvett",
Copy				: "Avrita",
Paste				: "Innrita",
PasteText			: "Innrita reinan tekst",
PasteWord			: "Innrita frá Word",
Print				: "Prenta",
SelectAll			: "Markera alt",
RemoveFormat		: "Strika sniðgeving",
InsertLinkLbl		: "Tilknýti",
InsertLink			: "Ger/broyt tilknýti",
RemoveLink			: "Strika tilknýti",
VisitLink			: "Opna tilknýti",
Anchor				: "Ger/broyt marknastein",
AnchorDelete		: "Strika marknastein",
InsertImageLbl		: "Myndir",
InsertImage			: "Set inn/broyt mynd",
InsertFlashLbl		: "Flash",
InsertFlash			: "Set inn/broyt Flash",
InsertTableLbl		: "Tabell",
InsertTable			: "Set inn/broyt tabell",
InsertLineLbl		: "Linja",
InsertLine			: "Ger vatnrætta linju",
InsertSpecialCharLbl: "Sertekn",
InsertSpecialChar	: "Set inn sertekn",
InsertSmileyLbl		: "Smiley",
InsertSmiley		: "Set inn Smiley",
About				: "Um FCKeditor",
Bold				: "Feit skrift",
Italic				: "Skráskrift",
Underline			: "Undirstrikað",
StrikeThrough		: "Yvirstrikað",
Subscript			: "Lækkað skrift",
Superscript			: "Hækkað skrift",
LeftJustify			: "Vinstrasett",
CenterJustify		: "Miðsett",
RightJustify		: "Høgrasett",
BlockJustify		: "Javnir tekstkantar",
DecreaseIndent		: "Minka reglubrotarinntriv",
IncreaseIndent		: "Økja reglubrotarinntriv",
Blockquote			: "Blockquote",
CreateDiv			: "Ger DIV øki",
EditDiv				: "Broyt DIV øki",
DeleteDiv			: "Strika DIV øki",
Undo				: "Angra",
Redo				: "Vend aftur",
NumberedListLbl		: "Talmerktur listi",
NumberedList		: "Ger/strika talmerktan lista",
BulletedListLbl		: "Punktmerktur listi",
BulletedList		: "Ger/strika punktmerktan lista",
ShowTableBorders	: "Vís tabellbordar",
ShowDetails			: "Vís í smálutum",
Style				: "Typografi",
FontFormat			: "Skriftsnið",
Font				: "Skrift",
FontSize			: "Skriftstødd",
TextColor			: "Tekstlitur",
BGColor				: "Bakgrundslitur",
Source				: "Kelda",
Find				: "Leita",
Replace				: "Yvirskriva",
SpellCheck			: "Kanna stavseting",
UniversalKeyboard	: "Knappaborð",
PageBreakLbl		: "Síðuskift",
PageBreak			: "Ger síðuskift",

Form			: "Formur",
Checkbox		: "Flugubein",
RadioButton		: "Radioknøttur",
TextField		: "Tekstteigur",
Textarea		: "Tekstumráði",
HiddenField		: "Fjaldur teigur",
Button			: "Knøttur",
SelectionField	: "Valskrá",
ImageButton		: "Myndaknøttur",

FitWindow		: "Set tekstviðgera til fulla stødd",
ShowBlocks		: "Vís blokkar",

// Context Menu
EditLink			: "Broyt tilknýti",
CellCM				: "Meski",
RowCM				: "Rað",
ColumnCM			: "Kolonna",
InsertRowAfter		: "Set rað inn aftaná",
InsertRowBefore		: "Set rað inn áðrenn",
DeleteRows			: "Strika røðir",
InsertColumnAfter	: "Set kolonnu inn aftaná",
InsertColumnBefore	: "Set kolonnu inn áðrenn",
DeleteColumns		: "Strika kolonnur",
InsertCellAfter		: "Set meska inn aftaná",
InsertCellBefore	: "Set meska inn áðrenn",
DeleteCells			: "Strika meskar",
MergeCells			: "Flætta meskar",
MergeRight			: "Flætta meskar til høgru",
MergeDown			: "Flætta saman",
HorizontalSplitCell	: "Kloyv meska vatnrætt",
VerticalSplitCell	: "Kloyv meska loddrætt",
TableDelete			: "Strika tabell",
CellProperties		: "Meskueginleikar",
TableProperties		: "Tabelleginleikar",
ImageProperties		: "Myndaeginleikar",
FlashProperties		: "Flash eginleikar",

AnchorProp			: "Eginleikar fyri marknastein",
ButtonProp			: "Eginleikar fyri knøtt",
CheckboxProp		: "Eginleikar fyri flugubein",
HiddenFieldProp		: "Eginleikar fyri fjaldan teig",
RadioButtonProp		: "Eginleikar fyri radioknøtt",
ImageButtonProp		: "Eginleikar fyri myndaknøtt",
TextFieldProp		: "Eginleikar fyri tekstteig",
SelectionFieldProp	: "Eginleikar fyri valskrá",
TextareaProp		: "Eginleikar fyri tekstumráði",
FormProp			: "Eginleikar fyri Form",

FontFormats			: "Vanligt;Sniðgivið;Adressa;Yvirskrift 1;Yvirskrift 2;Yvirskrift 3;Yvirskrift 4;Yvirskrift 5;Yvirskrift 6",

// Alerts and Messages
ProcessingXHTML		: "XHTML verður viðgjørt. Bíða við...",
Done				: "Liðugt",
PasteWordConfirm	: "Teksturin, royndur verður at seta inn, tykist at stava frá Word. Vilt tú reinsa tekstin, áðrenn hann verður settur inn?",
NotCompatiblePaste	: "Hetta er bert tøkt í Internet Explorer 5.5 og nýggjari. Vilt tú seta tekstin inn kortini - óreinsaðan?",
UnknownToolbarItem	: "Ókendur lutur í amboðsbjálkanum \"%1\"",
UnknownCommand		: "Ókend kommando \"%1\"",
NotImplemented		: "Hetta er ikki tøkt í hesi útgávuni",
UnknownToolbarSet	: "Amboðsbjálkin \"%1\" finst ikki",
NoActiveX			: "Trygdaruppsetingin í alnótskaganum kann sum er avmarka onkrar hentleikar í tekstviðgeranum. Tú mást loyva møguleikanum \"Run/Kør ActiveX controls and plug-ins\". Tú kanst uppliva feilir og ávaringar um tvørrandi hentleikar.",
BrowseServerBlocked : "Ambætarakagin kundi ikki opnast. Tryggja tær, at allar pop-up forðingar eru óvirknar.",
DialogBlocked		: "Tað eyðnaðist ikki at opna samskiftisrútin. Tryggja tær, at allar pop-up forðingar eru óvirknar.",
VisitLinkBlocked	: "Tað eyðnaðist ikki at opna nýggjan rút. Tryggja tær, at allar pop-up forðingar eru óvirknar.",

// Dialogs
DlgBtnOK			: "Góðkent",
DlgBtnCancel		: "Avlýst",
DlgBtnClose			: "Lat aftur",
DlgBtnBrowseServer	: "Ambætarakagi",
DlgAdvancedTag		: "Fjølbroytt",
DlgOpOther			: "<Annað>",
DlgInfoTab			: "Upplýsingar",
DlgAlertUrl			: "Vinarliga veit ein URL",

// General Dialogs Labels
DlgGenNotSet		: "<ikki sett>",
DlgGenId			: "Id",
DlgGenLangDir		: "Tekstkós",
DlgGenLangDirLtr	: "Frá vinstru til høgru (LTR)",
DlgGenLangDirRtl	: "Frá høgru til vinstru (RTL)",
DlgGenLangCode		: "Málkoda",
DlgGenAccessKey		: "Snarvegisknappur",
DlgGenName			: "Navn",
DlgGenTabIndex		: "Inntriv indeks",
DlgGenLongDescr		: "Víðkað URL frágreiðing",
DlgGenClass			: "Typografi klassar",
DlgGenTitle			: "Vegleiðandi heiti",
DlgGenContType		: "Vegleiðandi innihaldsslag",
DlgGenLinkCharset	: "Atknýtt teknsett",
DlgGenStyle			: "Typografi",

// Image Dialog
DlgImgTitle			: "Myndaeginleikar",
DlgImgInfoTab		: "Myndaupplýsingar",
DlgImgBtnUpload		: "Send til ambætaran",
DlgImgURL			: "URL",
DlgImgUpload		: "Send",
DlgImgAlt			: "Alternativur tekstur",
DlgImgWidth			: "Breidd",
DlgImgHeight		: "Hædd",
DlgImgLockRatio		: "Læs lutfallið",
DlgBtnResetSize		: "Upprunastødd",
DlgImgBorder		: "Bordi",
DlgImgHSpace		: "Høgri breddi",
DlgImgVSpace		: "Vinstri breddi",
DlgImgAlign			: "Justering",
DlgImgAlignLeft		: "Vinstra",
DlgImgAlignAbsBottom: "Abs botnur",
DlgImgAlignAbsMiddle: "Abs miðja",
DlgImgAlignBaseline	: "Basislinja",
DlgImgAlignBottom	: "Botnur",
DlgImgAlignMiddle	: "Miðja",
DlgImgAlignRight	: "Høgra",
DlgImgAlignTextTop	: "Tekst toppur",
DlgImgAlignTop		: "Ovast",
DlgImgPreview		: "Frumsýning",
DlgImgAlertUrl		: "Rita slóðina til myndina",
DlgImgLinkTab		: "Tilknýti",

// Flash Dialog
DlgFlashTitle		: "Flash eginleikar",
DlgFlashChkPlay		: "Avspælingin byrjar sjálv",
DlgFlashChkLoop		: "Endurspæl",
DlgFlashChkMenu		: "Ger Flash skrá virkna",
DlgFlashScale		: "Skalering",
DlgFlashScaleAll	: "Vís alt",
DlgFlashScaleNoBorder	: "Eingin bordi",
DlgFlashScaleFit	: "Neyv skalering",

// Link Dialog
DlgLnkWindowTitle	: "Tilknýti",
DlgLnkInfoTab		: "Tilknýtis upplýsingar",
DlgLnkTargetTab		: "Mál",

DlgLnkType			: "Tilknýtisslag",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Tilknýti til marknastein í tekstinum",
DlgLnkTypeEMail		: "Teldupostur",
DlgLnkProto			: "Protokoll",
DlgLnkProtoOther	: "<Annað>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Vel ein marknastein",
DlgLnkAnchorByName	: "Eftir navni á marknasteini",
DlgLnkAnchorById	: "Eftir element Id",
DlgLnkNoAnchors		: "(Eingir marknasteinar eru í hesum dokumentið)",
DlgLnkEMail			: "Teldupost-adressa",
DlgLnkEMailSubject	: "Evni",
DlgLnkEMailBody		: "Breyðtekstur",
DlgLnkUpload		: "Send til ambætaran",
DlgLnkBtnUpload		: "Send til ambætaran",

DlgLnkTarget		: "Mál",
DlgLnkTargetFrame	: "<ramma>",
DlgLnkTargetPopup	: "<popup vindeyga>",
DlgLnkTargetBlank	: "Nýtt vindeyga (_blank)",
DlgLnkTargetParent	: "Upphavliga vindeygað (_parent)",
DlgLnkTargetSelf	: "Sama vindeygað (_self)",
DlgLnkTargetTop		: "Alt vindeygað (_top)",
DlgLnkTargetFrameName	: "Vís navn vindeygans",
DlgLnkPopWinName	: "Popup vindeygans navn",
DlgLnkPopWinFeat	: "Popup vindeygans víðkaðu eginleikar",
DlgLnkPopResize		: "Kann broyta stødd",
DlgLnkPopLocation	: "Adressulinja",
DlgLnkPopMenu		: "Skrábjálki",
DlgLnkPopScroll		: "Rullibjálki",
DlgLnkPopStatus		: "Støðufrágreiðingarbjálki",
DlgLnkPopToolbar	: "Amboðsbjálki",
DlgLnkPopFullScrn	: "Fullur skermur (IE)",
DlgLnkPopDependent	: "Bundið (Netscape)",
DlgLnkPopWidth		: "Breidd",
DlgLnkPopHeight		: "Hædd",
DlgLnkPopLeft		: "Frástøða frá vinstru",
DlgLnkPopTop		: "Frástøða frá íerva",

DlnLnkMsgNoUrl		: "Vinarliga skriva tilknýti (URL)",
DlnLnkMsgNoEMail	: "Vinarliga skriva teldupost-adressu",
DlnLnkMsgNoAnchor	: "Vinarliga vel marknastein",
DlnLnkMsgInvPopName	: "Popup navnið má byrja við bókstavi og má ikki hava millumrúm",

// Color Dialog
DlgColorTitle		: "Vel lit",
DlgColorBtnClear	: "Strika alt",
DlgColorHighlight	: "Framhevja",
DlgColorSelected	: "Valt",

// Smiley Dialog
DlgSmileyTitle		: "Vel Smiley",

// Special Character Dialog
DlgSpecialCharTitle	: "Vel sertekn",

// Table Dialog
DlgTableTitle		: "Eginleikar fyri tabell",
DlgTableRows		: "Røðir",
DlgTableColumns		: "Kolonnur",
DlgTableBorder		: "Bordabreidd",
DlgTableAlign		: "Justering",
DlgTableAlignNotSet	: "<Einki valt>",
DlgTableAlignLeft	: "Vinstrasett",
DlgTableAlignCenter	: "Miðsett",
DlgTableAlignRight	: "Høgrasett",
DlgTableWidth		: "Breidd",
DlgTableWidthPx		: "pixels",
DlgTableWidthPc		: "prosent",
DlgTableHeight		: "Hædd",
DlgTableCellSpace	: "Fjarstøða millum meskar",
DlgTableCellPad		: "Meskubreddi",
DlgTableCaption		: "Tabellfrágreiðing",
DlgTableSummary		: "Samandráttur",

// Table Cell Dialog
DlgCellTitle		: "Mesku eginleikar",
DlgCellWidth		: "Breidd",
DlgCellWidthPx		: "pixels",
DlgCellWidthPc		: "prosent",
DlgCellHeight		: "Hædd",
DlgCellWordWrap		: "Orðkloyving",
DlgCellWordWrapNotSet	: "<Einki valt>",
DlgCellWordWrapYes	: "Ja",
DlgCellWordWrapNo	: "Nei",
DlgCellHorAlign		: "Vatnrøtt justering",
DlgCellHorAlignNotSet	: "<Einki valt>",
DlgCellHorAlignLeft	: "Vinstrasett",
DlgCellHorAlignCenter	: "Miðsett",
DlgCellHorAlignRight: "Høgrasett",
DlgCellVerAlign		: "Lodrøtt justering",
DlgCellVerAlignNotSet	: "<Ikki sett>",
DlgCellVerAlignTop	: "Ovast",
DlgCellVerAlignMiddle	: "Miðjan",
DlgCellVerAlignBottom	: "Niðast",
DlgCellVerAlignBaseline	: "Basislinja",
DlgCellRowSpan		: "Røðir, meskin fevnir um",
DlgCellCollSpan		: "Kolonnur, meskin fevnir um",
DlgCellBackColor	: "Bakgrundslitur",
DlgCellBorderColor	: "Litur á borda",
DlgCellBtnSelect	: "Vel...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Finn og broyt",

// Find Dialog
DlgFindTitle		: "Finn",
DlgFindFindBtn		: "Finn",
DlgFindNotFoundMsg	: "Leititeksturin varð ikki funnin",

// Replace Dialog
DlgReplaceTitle			: "Yvirskriva",
DlgReplaceFindLbl		: "Finn:",
DlgReplaceReplaceLbl	: "Yvirskriva við:",
DlgReplaceCaseChk		: "Munur á stórum og smáðum bókstavum",
DlgReplaceReplaceBtn	: "Yvirskriva",
DlgReplaceReplAllBtn	: "Yvirskriva alt",
DlgReplaceWordChk		: "Bert heil orð",

// Paste Operations / Dialog
PasteErrorCut	: "Trygdaruppseting alnótskagans forðar tekstviðgeranum í at kvetta tekstin. Vinarliga nýt knappaborðið til at kvetta tekstin (CTRL+X).",
PasteErrorCopy	: "Trygdaruppseting alnótskagans forðar tekstviðgeranum í at avrita tekstin. Vinarliga nýt knappaborðið til at avrita tekstin (CTRL+C).",

PasteAsText		: "Innrita som reinan tekst",
PasteFromWord	: "Innrita fra Word",

DlgPasteMsg2	: "Vinarliga koyr tekstin í hendan rútin við knappaborðinum (<strong>CTRL+V</strong>) og klikk á <strong>Góðtak</strong>.",
DlgPasteSec		: "Trygdaruppseting alnótskagans forðar tekstviðgeranum í beinleiðis atgongd til avritingarminnið. Tygum mugu royna aftur í hesum rútinum.",
DlgPasteIgnoreFont		: "Forfjóna Font definitiónirnar",
DlgPasteRemoveStyles	: "Strika typografi definitiónir",

// Color Picker
ColorAutomatic	: "Automatiskt",
ColorMoreColors	: "Fleiri litir...",

// Document Properties
DocProps		: "Eginleikar fyri dokument",

// Anchor Dialog
DlgAnchorTitle		: "Eginleikar fyri marknastein",
DlgAnchorName		: "Heiti marknasteinsins",
DlgAnchorErrorName	: "Vinarliga rita marknasteinsins heiti",

// Speller Pages Dialog
DlgSpellNotInDic		: "Finst ikki í orðabókini",
DlgSpellChangeTo		: "Broyt til",
DlgSpellBtnIgnore		: "Forfjóna",
DlgSpellBtnIgnoreAll	: "Forfjóna alt",
DlgSpellBtnReplace		: "Yvirskriva",
DlgSpellBtnReplaceAll	: "Yvirskriva alt",
DlgSpellBtnUndo			: "Angra",
DlgSpellNoSuggestions	: "- Einki uppskot -",
DlgSpellProgress		: "Rættstavarin arbeiðir...",
DlgSpellNoMispell		: "Rættstavarain liðugur: Eingin feilur funnin",
DlgSpellNoChanges		: "Rættstavarain liðugur: Einki orð varð broytt",
DlgSpellOneChange		: "Rættstavarain liðugur: Eitt orð er broytt",
DlgSpellManyChanges		: "Rættstavarain liðugur: %1 orð broytt",

IeSpellDownload			: "Rættstavarin er ikki tøkur í tekstviðgeranum. Vilt tú heinta hann nú?",

// Button Dialog
DlgButtonText		: "Tekstur",
DlgButtonType		: "Slag",
DlgButtonTypeBtn	: "Knøttur",
DlgButtonTypeSbm	: "Send",
DlgButtonTypeRst	: "Nullstilla",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Navn",
DlgCheckboxValue	: "Virði",
DlgCheckboxSelected	: "Valt",

// Form Dialog
DlgFormName		: "Navn",
DlgFormAction	: "Hending",
DlgFormMethod	: "Háttur",

// Select Field Dialog
DlgSelectName		: "Navn",
DlgSelectValue		: "Virði",
DlgSelectSize		: "Stødd",
DlgSelectLines		: "Linjur",
DlgSelectChkMulti	: "Loyv fleiri valmøguleikum samstundis",
DlgSelectOpAvail	: "Tøkir møguleikar",
DlgSelectOpText		: "Tekstur",
DlgSelectOpValue	: "Virði",
DlgSelectBtnAdd		: "Legg afturat",
DlgSelectBtnModify	: "Broyt",
DlgSelectBtnUp		: "Upp",
DlgSelectBtnDown	: "Niður",
DlgSelectBtnSetValue : "Set sum valt virði",
DlgSelectBtnDelete	: "Strika",

// Textarea Dialog
DlgTextareaName	: "Navn",
DlgTextareaCols	: "kolonnur",
DlgTextareaRows	: "røðir",

// Text Field Dialog
DlgTextName			: "Navn",
DlgTextValue		: "Virði",
DlgTextCharWidth	: "Breidd (sjónlig tekn)",
DlgTextMaxChars		: "Mest loyvdu tekn",
DlgTextType			: "Slag",
DlgTextTypeText		: "Tekstur",
DlgTextTypePass		: "Loyniorð",

// Hidden Field Dialog
DlgHiddenName	: "Navn",
DlgHiddenValue	: "Virði",

// Bulleted List Dialog
BulletedListProp	: "Eginleikar fyri punktmerktan lista",
NumberedListProp	: "Eginleikar fyri talmerktan lista",
DlgLstStart			: "Byrjan",
DlgLstType			: "Slag",
DlgLstTypeCircle	: "Sirkul",
DlgLstTypeDisc		: "Fyltur sirkul",
DlgLstTypeSquare	: "Fjórhyrningur",
DlgLstTypeNumbers	: "Talmerkt (1, 2, 3)",
DlgLstTypeLCase		: "Smáir bókstavir (a, b, c)",
DlgLstTypeUCase		: "Stórir bókstavir (A, B, C)",
DlgLstTypeSRoman	: "Smá rómaratøl (i, ii, iii)",
DlgLstTypeLRoman	: "Stór rómaratøl (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Generelt",
DlgDocBackTab		: "Bakgrund",
DlgDocColorsTab		: "Litir og breddar",
DlgDocMetaTab		: "META-upplýsingar",

DlgDocPageTitle		: "Síðuheiti",
DlgDocLangDir		: "Tekstkós",
DlgDocLangDirLTR	: "Frá vinstru móti høgru (LTR)",
DlgDocLangDirRTL	: "Frá høgru móti vinstru (RTL)",
DlgDocLangCode		: "Málkoda",
DlgDocCharSet		: "Teknsett koda",
DlgDocCharSetCE		: "Miðeuropa",
DlgDocCharSetCT		: "Kinesiskt traditionelt (Big5)",
DlgDocCharSetCR		: "Cyrilliskt",
DlgDocCharSetGR		: "Grikst",
DlgDocCharSetJP		: "Japanskt",
DlgDocCharSetKR		: "Koreanskt",
DlgDocCharSetTR		: "Turkiskt",
DlgDocCharSetUN		: "UNICODE (UTF-8)",
DlgDocCharSetWE		: "Vestureuropa",
DlgDocCharSetOther	: "Onnur teknsett koda",

DlgDocDocType		: "Dokumentslag yvirskrift",
DlgDocDocTypeOther	: "Annað dokumentslag yvirskrift",
DlgDocIncXHTML		: "Viðfest XHTML deklaratiónir",
DlgDocBgColor		: "Bakgrundslitur",
DlgDocBgImage		: "Leið til bakgrundsmynd (URL)",
DlgDocBgNoScroll	: "Læst bakgrund (rullar ikki)",
DlgDocCText			: "Tekstur",
DlgDocCLink			: "Tilknýti",
DlgDocCVisited		: "Vitjaði tilknýti",
DlgDocCActive		: "Virkin tilknýti",
DlgDocMargins		: "Síðubreddar",
DlgDocMaTop			: "Ovast",
DlgDocMaLeft		: "Vinstra",
DlgDocMaRight		: "Høgra",
DlgDocMaBottom		: "Niðast",
DlgDocMeIndex		: "Dokument index lyklaorð (sundurbýtt við komma)",
DlgDocMeDescr		: "Dokumentlýsing",
DlgDocMeAuthor		: "Høvundur",
DlgDocMeCopy		: "Upphavsrættindi",
DlgDocPreview		: "Frumsýning",

// Templates Dialog
Templates			: "Skabelónir",
DlgTemplatesTitle	: "Innihaldsskabelónir",
DlgTemplatesSelMsg	: "Vinarliga vel ta skabelón, ið skal opnast í tekstviðgeranum<br>(Hetta yvirskrivar núverandi innihald):",
DlgTemplatesLoading	: "Heinti yvirlit yvir skabelónir. Vinarliga bíða við...",
DlgTemplatesNoTpl	: "(Ongar skabelónir tøkar)",
DlgTemplatesReplace	: "Yvirskriva núverandi innihald",

// About Dialog
DlgAboutAboutTab	: "Um",
DlgAboutBrowserInfoTab	: "Upplýsingar um alnótskagan",
DlgAboutLicenseTab	: "License",
DlgAboutVersion		: "version",
DlgAboutInfo		: "Fyri fleiri upplýsingar, far til",

// Div Dialog
DlgDivGeneralTab	: "Generelt",
DlgDivAdvancedTab	: "Fjølbroytt",
DlgDivStyle		: "Typografi",
DlgDivInlineStyle	: "Inline typografi"
};
